@@ -5,6 +5,7 @@
 pub mod core;
 
 use std::collections::HashSet;
+use std::fmt::{self, Formatter};
 use std::time::Duration;
 
 use self::core::{
@@ -76,8 +77,8 @@ pub struct CsrfHandler {
     protect: AesGcmCsrfProtection,
 }
 
-impl std::fmt::Debug for CsrfHandler {
-    fn fmt(&self, f: &mut std::fmt::Formatter<'_>) -> std::fmt::Result {
+impl fmt::Debug for CsrfHandler {
+    fn fmt(&self, f: &mut Formatter<'_>) -> fmt::Result {
         f.debug_struct("CsrfHandler")
             .field("cookie_path", &self.cookie_path)
             .field("cookie_name", &self.cookie_name)
@@ -230,7 +231,7 @@ impl CsrfHandler {
         // location. And we can't use `or_else` chaining since the
         // function that searches through the form body is async. Note
         // that if parsing the body fails then we want to returns an
-        // InternalServerError, hence the `?`. This is not the same as
+        // StatusError::internal_server_error(), hence the `?`. This is not the same as
         // what we will do later, which is convert failures to *parse* a
         // found CSRF token into Forbidden responses.
         let csrf_token = if let Some(csrf_token) = self.find_csrf_token_in_header(req) {
@@ -240,11 +241,9 @@ impl CsrfHandler {
         } else if let Some(csrf_token) = self.find_csrf_token_in_form(req).await {
             csrf_token
         } else {
-            return Err(Error::custom("csrf", "not found"));
+            return Err(Error::other("not found"));
         };
-        self.protect
-            .parse_token(&csrf_token)
-            .map_err(|e| Error::custom("csrf", e))
+        self.protect.parse_token(&csrf_token).map_err(Error::other)
     }
 
     fn find_csrf_token_in_header(&self, req: &Request) -> Option<Vec<u8>> {
