@@ -8,7 +8,7 @@ use once_cell::sync::Lazy;
 use serde::de::DeserializeOwned;
 
 use salvo_core::async_trait;
-use salvo_core::http::errors::*;
+use salvo_core::http::errors::StatusError;
 use salvo_core::http::header::AUTHORIZATION;
 use salvo_core::http::{Method, Request, Response};
 use salvo_core::routing::FlowCtrl;
@@ -354,7 +354,7 @@ where
                 } else {
                     depot.insert(AUTH_STATE_KEY, JwtAuthState::Forbidden);
                     if self.response_error {
-                        res.set_status_error(Forbidden());
+                        res.set_status_error(StatusError::forbidden());
                         ctrl.skip_reset();
                     }
                 }
@@ -365,7 +365,7 @@ where
         }
         depot.insert(AUTH_STATE_KEY, JwtAuthState::Unauthorized);
         if self.response_error {
-            res.set_status_error(Unauthorized());
+            res.set_status_error(StatusError::unauthorized());
             ctrl.skip_reset();
         } else {
             ctrl.call_next(req, depot, res).await;
